package com.kingtom.lightflow.approvalimpl;

import cn.hutool.core.lang.Assert;
import com.kingtom.lightflow.LightFlowConst;
import com.kingtom.lightflow.engine.cxt.FlowContext;
import com.kingtom.lightflow.engine.ext.IFlowConnectHandler;
import com.kingtom.lightflow.engine.ext.IFlowHandler;
import com.kingtom.lightflow.engine.ext.IFlowObjectHandler;
import com.kingtom.kirin.core.common.exception.AppException;
import lombok.extern.slf4j.Slf4j;

import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 * Copyright: Copyright (C) 2024 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2024/1/30 14:56
 */
@Slf4j
public class ApprovalFlowHandler implements IFlowHandler {

    protected Map<String,IFlowObjectHandler> objectHandlerMap = new HashMap<>();

    protected Map<String,IFlowConnectHandler> connectHandlerMap = new HashMap<>();

    public ApprovalFlowHandler() {
        init();
    }

    protected void init() {
//        String json = ResourceUtil.readStr(CONF_APPROVAL, StandardCharsets.UTF_8);
//        FlowApprovalConf conf = JsonUtils.toObject(json, FlowApprovalConf.class);
//        try{
//            for(String cstr:conf.getConnectHandlers()) {
//                IFlowConnectHandler connectHandler = (IFlowConnectHandler)ClassUtil.loadClass(cstr).getDeclaredConstructor().newInstance();
//                putConnecttHandler(connectHandler);
//            }
//            for(String ostr:conf.getObjectHandlers()) {
//                IFlowObjectHandler objectHandler = (IFlowObjectHandler)ClassUtil.loadClass(ostr).getDeclaredConstructor().newInstance();
//                putObjectHandler(objectHandler);
//            }
//            log.info("审批流加载完成：conf="+JsonUtils.toJson(conf));
//        } catch (Exception e) {
//            throw new AppException("审批流加载失败",e);
//        }
    }

    public void putObjectHandler(IFlowObjectHandler objectHandler) {
        Assert.isFalse(objectHandler==null,()->new AppException("审批流节点实现不能为空"));
        Assert.isFalse(objectHandler.defineType()==null,()->new AppException("审批流节点实现不能没有类型名"));
        Assert.isFalse(objectHandlerMap.containsKey(objectHandler.defineType()),()->new AppException("审批流节点实现冲突").setM(objectHandler.defineType()));
        objectHandlerMap.put(objectHandler.defineType(),objectHandler);
    }

    public void putConnecttHandler(IFlowConnectHandler connectHandler) {
        Assert.isFalse(connectHandler==null,()->new AppException("审批流连接实现不能为空"));
        Assert.isFalse(connectHandler.defineType()==null,()->new AppException("审批流连接实现不能没有类型名"));
        Assert.isFalse(connectHandlerMap.containsKey(connectHandler.defineType()),()->new AppException("审批流连接实现冲突").setM(connectHandler.defineType()));
        connectHandlerMap.put(connectHandler.defineType(),connectHandler);
    }

    /**
     * 申明自己针对的流程类型
     *
     * @return
     */
    @Override
    public String defineName() {
        return LightFlowConst.FLOW_Approval;
    }

    /**
     * 在流程实例启动时填充FlowContext
     *
     * @param context
     */
    @Override
    public void fillFlowContext(FlowContext context) {

    }

    /**
     * 查找节点处理器
     *
     * @param objectType
     * @return
     */
    @Override
    public IFlowObjectHandler findFlowObjectHandler(String objectType) {
        return objectHandlerMap.get(objectType);
    }

    public void registFlowObjectHandler(IFlowObjectHandler objectHandler) {
        Assert.isFalse(objectHandler == null,()->new AppException("流程对象解释器不能为空"));
        objectHandlerMap.put(objectHandler.defineType(),objectHandler);
    }

    public void registFlowConnectObjectHandler(IFlowConnectHandler connectHandler) {
        Assert.isFalse(connectHandler == null,()->new AppException("流程连接解释器不能为空"));
        connectHandlerMap.put(connectHandler.defineType(),connectHandler);
    }

    /**
     * 查找连接处理器
     *
     * @param connectType
     * @return
     */
    @Override
    public IFlowConnectHandler findFlowConnectHandler(String connectType) {
        return connectHandlerMap.get(connectType);
    }

}
