package com.kingtom.lightflow.approvalimpl;

import cn.hutool.core.io.resource.ResourceUtil;
import com.kingtom.lightflow.engine.model.biz.FlowDef;
import com.kingtom.lightflow.engineimpl.service.IFlowDesignService;
import com.kingtom.lightflow.engineimpl.service.IFlowRunService;
import com.kingtom.lightflow.engine.core.FlowEngine;
import com.kingtom.lightflow.engine.core.FlowEngineFactory;
import com.kingtom.lightflow.engine.cxt.FlowInput;
import com.kingtom.lightflow.engine.cxt.FlowOutput;
import com.kingtom.kirin.core.common.base.Result;
import com.kingtom.kirin.core.common.utils.JsonUtils;
import lombok.extern.slf4j.Slf4j;

import java.nio.charset.StandardCharsets;
import java.util.List;

/**
 * <p>
 * Copyright: Copyright (C) 2024 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 * 轻流：审批流测试类
 * @author King
 * @since 2024/2/20 14:42
 */
@Slf4j
public class ApprovalFlowTest {

    private static final String TESTFLOW = "classpath:flowdemo/testFlow.json";

    public static void main(String[] args) {
        FlowEngine engine = FlowEngineFactory.getEngine();
        IFlowDesignService designService = null;
        IFlowRunService runService = null;
        // 发布流程
        String json = ResourceUtil.readStr(TESTFLOW, StandardCharsets.UTF_8);
        FlowDef flow = JsonUtils.toObject(json, FlowDef.class);
        Result<String> def = designService.doAdd(flow, true);
        String defId = def.getData();
        log.info("发布的流程ID="+defId);

        // 启动流程
        FlowInput input = new FlowInput();
        FlowOutput output = runService.doStart(defId, input, new FlowOutput());
        String entryId = (String)output.findMap().get("Result");
        log.info("发布的流程实例ID="+entryId);

        // 推动流程：完成任务
        List<String> taskIds = (List<String>)output.findMap().get("Task");
        for(String taskId:taskIds) {
            input = new FlowInput();
            output = runService.doTask(taskId, input, new FlowOutput());
            log.info("流程任务执行成功，ID="+taskId);
        }
    }

}
