package com.kingtom.lightflow.engine;

import com.kingtom.kirin.core.common.base.IBaseEnum;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/12/22 16:31
 */
public class FlowEngineConst {

    public static final String DEFAULT_CONF = "classpath:flow/flow_core_conf.json";

    public static final String Flow_event_start = "flow:event:start";
    @Deprecated
    public static final String Flow_event_mid = "flow:event:mid";
    public static final String Flow_event_end = "flow:event:end";
    public static final String Flow_activity_task_shenpi = "flow:activity:task:shenpi";
    public static final String Flow_activity_task_xiezuo = "flow:activity:task:xiezuo";
    @Deprecated
    public static final String Flow_activity_subflow = "flow:activity:subflow";
    @Deprecated
    public static final String Flow_gateway_xor = "flow:gateway:xor";
    @Deprecated
    public static final String Flow_gateway_para = "flow:gateway:para";
    public static final String Flow_gateway_mult = "flow:gateway:mult";
    public static final String Connect_sequence = "connect:sequence";
    @Deprecated
    public static final String Connect_message = "connect:message";
    @Deprecated
    public static final String Connect_associat = "connect:associat";

    /**
     * BPMN2.0内容
     * 1、流对象（Flow Objects）：流对象是定义业务流程的主要图形元素，主要有三种流对象
     * 事件（Events）（开始、中间、结束）
     * 活动（Activities）（任务、子流程）
     * 网关（Gateways）（排他网关、并行网关、包容网关）
     * 2、数据（Data）：数据主要通过四种元素表示
     * 数据对象（Data Objects）
     * 数据输入（Data Inputs）
     * 数据输出（Data Outputs）
     * 数据存储（Data Stores）
     * 3、连接对象（Connecting Objects）：流对象彼此互相连接或者连接到其他信息的方法主要有四种
     * 顺序流（Sequence Flows）
     * 信息流（Message Flows）
     * 协同（Associations）
     * 数据协同（Data Associations）
     * 4、泳道（Swimlanes）：有两种方式通过泳道对主要的建模元素进行分组
     * 泳池：Pools
     * 泳道：Lanes
     * 5、人工信息（Artifacts）：主要用来提供关于流程的额外信息。BPMN2.0定义两种标准Artifacts，但是建模者或者建模工具可以增加任意多Artifacts。（Artifacts，有的地方翻译成“工件”，但是感觉不管翻译成什么都不够传神，所以本文中就不翻译这个词了。）
     * 组：Group
     * 文本注释：Text Annotation
     *
     * 本期支持内容如下（见上方静态变量）
     * flow:event:start（开始事件）
     * flow:event:mid（中间事件）-不支持
     * flow:event:end（结束事件）
     * flow:activity:task（任务活动）
     * flow:activity:task:xxxx（具体任务活动：业务自定义）
     * flow:activity:subflow（子流程活动）-不支持
     * flow:gateway:xor（排他网关）-不支持
     * flow:gateway:para（并行网关）-不支持
     * flow:gateway:mult（包容网关）
     * connect:sequence（顺序流）
     * connect:message（消息流）-不支持
     * connect:associat（协同）-不支持
     * 泳道-不支持
     * 人工信息-不支持
     */
    private FlowEngineConst() {}

    public static enum FlowStateEnum implements IBaseEnum<String> {
        UnDo("UnDo", "未处理"),
        DoProcess("DoProcess", "处理-进行中"),
        DoOver("DoOver", "处理-完成"),
        UnElapsed("UnElapsed", "未经过");

        private String key;

        private String name;

        private FlowStateEnum(String k, String n){
            this.key = k;
            this.name = n;
        }

        @Override
        public String getKey(){
            return key;
        }

        @Override
        public String getName(){
            return name;
        }

        public static FlowStateEnum findEnumByKey(String k){
            return IBaseEnum.findEnumByKey(FlowStateEnum.class, k);
        }
    }
}
