package com.kingtom.lightflow.engine.core;

import cn.hutool.core.lang.Assert;
import com.kingtom.lightflow.engine.ext.IFlowHandler;
import com.kingtom.lightflow.engine.ext.IFlowRoleHandler;
import com.kingtom.lightflow.engine.ext.IFlowStorageHandler;
import com.kingtom.kirin.core.common.exception.AppException;

import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 * Copyright: Copyright (C) 2024 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2024/1/9 17:58
 */
public class FlowConfigContainer {

    protected IFlowStorageHandler flowStorage;
    protected Map<String, IFlowHandler> flowHandlerMap = new HashMap<>();
    protected IFlowRoleHandler flowRoleHandler;

    public IFlowStorageHandler getFlowStorage() {
        return flowStorage;
    }

    public void setFlowStorage(IFlowStorageHandler storageHandler) {
        this.flowStorage = flowStorage;
    }

    public IFlowHandler findFlowHandler(String flowType) {
        return flowHandlerMap.get(flowType);
    }

    public IFlowRoleHandler getFlowRoleHandler() {
        return flowRoleHandler;
    }

    public void setFlowRoleHandler(IFlowRoleHandler flowRoleHandler) {
        this.flowRoleHandler = flowRoleHandler;
    }

    public void putFlowHandler(IFlowHandler flowHandler) {
        Assert.isFalse(flowHandler==null,()->new AppException("流程实现不能为空"));
        Assert.isFalse(flowHandler.defineName()==null,()->new AppException("流程实现不能没有类型名"));
        Assert.isFalse(flowHandlerMap.containsKey(flowHandler.defineName()),()->new AppException("流程实现冲突").setM(flowHandler.defineName()));
        flowHandlerMap.put(flowHandler.defineName(),flowHandler);
    }
}
