package com.kingtom.lightflow.engine.core;

import cn.hutool.core.io.resource.ResourceUtil;
import cn.hutool.core.util.ClassUtil;
import com.kingtom.lightflow.engine.FlowEngineConst;
import com.kingtom.lightflow.engine.ext.IFlowHandler;
import com.kingtom.lightflow.engine.ext.IFlowStorageHandler;
import com.kingtom.kirin.core.common.exception.AppException;
import com.kingtom.kirin.core.common.utils.JsonUtils;
import lombok.extern.slf4j.Slf4j;

import java.nio.charset.StandardCharsets;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/12/25 16:19
 */
@Slf4j
public class FlowEngineFactory {

    protected static FlowEngine flowEngine;

    protected static FlowConfigContainer flowConfigContainer;

    public static synchronized FlowEngine getEngine() {
        if(flowEngine == null) {
            FlowEngine r = new FlowEngine();
            FlowConfigContainer configContainer = findHandlerManager();
            r.setFlowConfigContainer(configContainer);
            flowEngine = r;
        }
        return flowEngine;
    }

    public static FlowConfigContainer findHandlerManager() {
        if(flowConfigContainer == null) {
            try{
                FlowConfigContainer h = new FlowConfigContainer();
                String json = ResourceUtil.readStr(FlowEngineConst.DEFAULT_CONF, StandardCharsets.UTF_8);
                FLowConfig conf = JsonUtils.toObject(json, FLowConfig.class);
                IFlowStorageHandler s = (IFlowStorageHandler)ClassUtil.loadClass(conf.getFlowStorage()).getDeclaredConstructor().newInstance();
                h.setFlowStorage(s);
                for(String handlerStr:conf.getFlowHandlers()) {
                    IFlowHandler flowHandler = (IFlowHandler)ClassUtil.loadClass(handlerStr).getDeclaredConstructor().newInstance();
                    h.putFlowHandler(flowHandler);
                }
                log.info("流程引擎加载完成：conf="+JsonUtils.toJson(conf));
                flowConfigContainer = h;
            } catch (Exception e) {
                throw new AppException("流程引擎加载错误",e);
            }
        }
        return flowConfigContainer;
    }

}
