DROP TABLE IF EXISTS "public"."affair_token";
-- ----------------------------
-- Table structure for affair_info
-- ----------------------------
DROP TABLE IF EXISTS "public"."affair_info";
CREATE TABLE "public"."affair_info" (
    "id"               VARCHAR(36) COLLATE "pg_catalog"."default"   NOT NULL PRIMARY KEY,
    "title"            VARCHAR(256) COLLATE "pg_catalog"."default"  NOT NULL,
    "summary"          VARCHAR(1024) COLLATE "pg_catalog"."default" NOT NULL,
    "source_type"      VARCHAR(64) COLLATE "pg_catalog"."default"   NOT NULL,
    "source_id"        VARCHAR(36) COLLATE "pg_catalog"."default"   NOT NULL,
    "type"             VARCHAR(64) COLLATE "pg_catalog"."default"   NOT NULL,
    "data"             TEXT COLLATE "pg_catalog"."default" DEFAULT '{}',
    "target"           TEXT COLLATE "pg_catalog"."default"          NOT NULL,
    "action_model"     VARCHAR(1024) COLLATE "pg_catalog"."default" NOT NULL,
    "effect_model"     VARCHAR(1024) COLLATE "pg_catalog"."default" NOT NULL,
    "effect_condition" VARCHAR(65534) COLLATE "pg_catalog"."default",
    "important"        VARCHAR(64) COLLATE "pg_catalog"."default"   NOT NULL,
    "urgent"           VARCHAR(64) COLLATE "pg_catalog"."default"   NOT NULL,
    "state"            int4                                         NOT NULL,
    "full_name"        VARCHAR(65534) COLLATE "pg_catalog"."default",
    "group_name"       VARCHAR(1024) COLLATE "pg_catalog"."default",
    "affair_token"     VARCHAR(65534) COLLATE "pg_catalog"."default",
    "affair_url"       VARCHAR(1024) COLLATE "pg_catalog"."default",
    "ext1"             VARCHAR(1024) COLLATE "pg_catalog"."default",
    "ext2"             VARCHAR(1024) COLLATE "pg_catalog"."default",
    "ext3"             TEXT COLLATE "pg_catalog"."default" DEFAULT '{}',
    "gmt_create"       TIMESTAMP(3)                                 NOT NULL,
    "gmt_modified"     TIMESTAMP(3)                                 NOT NULL,
    "sys_id"           VARCHAR(36) COLLATE "pg_catalog"."default"   NOT NULL
);
COMMENT ON TABLE "public"."affair_info" IS '事项表';
COMMENT ON COLUMN "public"."affair_info"."id" IS '主键';
COMMENT ON COLUMN "public"."affair_info"."title" IS '事项标题';
COMMENT ON COLUMN "public"."affair_info"."summary" IS '事项摘要描述';
COMMENT ON COLUMN "public"."affair_info"."source_type" IS '事项来源类型';
COMMENT ON COLUMN "public"."affair_info"."source_id" IS '事项来源Id';
COMMENT ON COLUMN "public"."affair_info"."type" IS '事项类型';
COMMENT ON COLUMN "public"."affair_info"."data" IS '业务数据';
COMMENT ON COLUMN "public"."affair_info"."target" IS '事项接收者';
COMMENT ON COLUMN "public"."affair_info"."action_model" IS '动作模式';
COMMENT ON COLUMN "public"."affair_info"."effect_model" IS '生效模式';
COMMENT ON COLUMN "public"."affair_info"."effect_condition" IS '生效条件';
COMMENT ON COLUMN "public"."affair_info"."important" IS '重要程度';
COMMENT ON COLUMN "public"."affair_info"."urgent" IS '紧急程度';
COMMENT ON COLUMN "public"."affair_info"."state" IS '事项状态';
COMMENT ON COLUMN "public"."affair_info"."full_name" IS '事项全称';
COMMENT ON COLUMN "public"."affair_info"."group_name" IS '事项分组名';
COMMENT ON COLUMN "public"."affair_info"."affair_token" IS '事项对接业务时的关键字（由业务识别）';
COMMENT ON COLUMN "public"."affair_info"."affair_url" IS '事项对接的URL';
COMMENT ON COLUMN "public"."affair_info"."ext1" IS '扩展字段1';
COMMENT ON COLUMN "public"."affair_info"."ext2" IS '扩展字段2';
COMMENT ON COLUMN "public"."affair_info"."ext2" IS '扩展字段3';
COMMENT ON COLUMN "public"."affair_info"."gmt_create" IS '创建时间';
COMMENT ON COLUMN "public"."affair_info"."gmt_modified" IS '更新时间';
COMMENT ON COLUMN "public"."affair_info"."sys_id" IS '系统ID';


-- ----------------------------
-- Table structure for affair_member
-- ----------------------------
DROP TABLE IF EXISTS "public"."affair_member";
CREATE TABLE "public"."affair_member" (
    "id"           VARCHAR(36) COLLATE "pg_catalog"."default" NOT NULL PRIMARY KEY,
    "affair_id"    VARCHAR(36) COLLATE "pg_catalog"."default" NOT NULL,
    "user_id"      VARCHAR(36) COLLATE "pg_catalog"."default" NOT NULL,
    "state"        int4                                       NOT NULL,
    "result"       int4,
    "data"         TEXT COLLATE "pg_catalog"."default" DEFAULT '{}',
    "ext1"         VARCHAR(1024) COLLATE "pg_catalog"."default",
    "ext2"         VARCHAR(1024) COLLATE "pg_catalog"."default",
    "ext3"         TEXT COLLATE "pg_catalog"."default" DEFAULT '{}',
    "gmt_create"   TIMESTAMP(3)                               NOT NULL,
    "gmt_modified" TIMESTAMP(3)                               NOT NULL,
    "sys_id"       VARCHAR(36) COLLATE "pg_catalog"."default" NOT NULL
);
COMMENT ON TABLE "public"."affair_member" IS '事项成员表';
COMMENT ON COLUMN "public"."affair_member"."id" IS '主键';
COMMENT ON COLUMN "public"."affair_member"."affair_id" IS '事项ID';
COMMENT ON COLUMN "public"."affair_member"."user_id" IS '用户ID';
COMMENT ON COLUMN "public"."affair_member"."state" IS '状态';
COMMENT ON COLUMN "public"."affair_member"."result" IS '处理结果';
COMMENT ON COLUMN "public"."affair_member"."data" IS '处理时提交的数据';
COMMENT ON COLUMN "public"."affair_member"."ext1" IS '扩展字段1';
COMMENT ON COLUMN "public"."affair_member"."ext2" IS '扩展字段2';
COMMENT ON COLUMN "public"."affair_member"."ext3" IS '扩展字段3';
COMMENT ON COLUMN "public"."affair_member"."gmt_create" IS '创建时间';
COMMENT ON COLUMN "public"."affair_member"."gmt_modified" IS '更新时间';
COMMENT ON COLUMN "public"."affair_member"."sys_id" IS '系统ID';
